unit BackupDatabase;

{$mode objfpc}{$H+}

interface


uses
  Classes, SysUtils, FileUtil, LResources, Forms, Controls, Graphics, Dialogs,
  StdCtrls, Buttons;

const
   Days : array [1 .. 7] of string[3] = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');

type

  { TfmBackupDatabase }

  TfmBackupDatabase = class(TForm)
    bbBackup: TBitBtn;
    BitBtn1: TBitBtn;
    edBackup: TEdit;
    edUser: TEdit;
    edPassword: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    laDatabase: TLabel;
    Memo1: TMemo;
    procedure bbBackupClick(Sender: TObject);
  private
    { private declarations }
  public
    procedure Init(Database, UserName, Password: string);
    { public declarations }
  end; 

var
  fmBackupDatabase: TfmBackupDatabase;

implementation

{ TfmBackupDatabase }

uses UnitFirebirdServices;

procedure TfmBackupDatabase.bbBackupClick(Sender: TObject);
var
  FileName: string;
  FireBirdServices: TFirebirdServices;
  Res: Ansistring;
  ADatabase: string;
  AHostName: string;
  TargetDatabase: string;
begin
  FireBirdServices:= nil;
  try

    TargetDatabase:= laDatabase.Caption;

    FileName:= edBackup.Text;
    if Pos('.', FileName) = 0 then
      FileName:= FileName + '.bkp';

    // Linux: servername:/path/test.fdb  or /path/test.fdb
    // Windows: servername:c:\path\test.fdb or c:\path\test.fdb
    if Pos(':', Trim(TargetDatabase)) > 2 then
    begin
      AHostName:= Trim(Copy(TargetDatabase, 1, Pos(':', TargetDatabase) - 1));
      TargetDatabase:= Trim(Copy(TargetDatabase, Pos(':', TargetDatabase) + 1, Length(TargetDatabase)));
    end
    else
      AHostName:= 'localhost';

    FileName:= ExtractFilePath(TargetDatabase) + FileName;

    FireBirdServices:= TFirebirdServices.Create;
    FireBirdServices.VerboseOutput:= True;
    with FireBirdServices do
    begin
      HostName:= AHostName;
      DBName:= TargetDatabase;
      UserName := edUser.Text;
      Password := edPassword.Text;
      BkpName := Trim(FileName);

      Memo1.Font.Color:= clBlack;
      Memo1.Clear;
      Memo1.Lines.Add('Host: ' + AHostName);
      Memo1.Lines.Add('Backup file: ' + FileName);

      try
        AttachService;

        StartBackup;

        while ServiceQuery(Res) do
          Memo1.Lines.Add(Res);

        if Memo1.Lines.Count > 5 then
          ShowMessage('تم نسخ قاعدة البيانات')
        else
          MessageDlg('لم يتم نسخ قاعدة البيانات', mtError, [mbOk], 0);

      finally
        DetachService;
      end;
      FireBirdServices.Free;
    end;

  except
    on e: exception do
    begin
      Memo1.Lines.Add(e.Message);
      Memo1.Font.Color:= clRed;
      if Assigned(FireBirdServices) then
        FireBirdServices.Free;
    end;
  end;

end;

procedure TfmBackupDatabase.Init(Database, UserName, Password: string);
var
  FileName: string;
begin
  Memo1.Clear;
  laDatabase.Caption:= Database;
  edUser.Text:= UserName;
  edPassword.Text:= Password;
  FileName:= ExtractFileName(Database);
    FileName:= ChangeFileExt(FileName, '');
  edBackup.Text:= FileName + '-' + Days[DayOfWeek(Now)];
end;

initialization
  {$I backupdatabase.lrs}

end.

