unit EntryForm;

{$mode objfpc}

interface

uses
  Classes, SysUtils, FileUtil, LResources, Forms, Controls, Graphics, Dialogs,
  StdCtrls, Buttons, Data;

type

  { TfmEntryForm }

  TfmEntryForm = class(TForm)
    bbCredit: TBitBtn;
    bbOk: TBitBtn;
    bbDebit: TBitBtn;
    cbDebitAccount: TComboBox;
    cbCreditAccount: TComboBox;
    edDetails: TEdit;
    edValue: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    laCurrency: TLabel;
    procedure bbCreditClick(Sender: TObject);
    procedure bbOkClick(Sender: TObject);
    procedure bbDebitClick(Sender: TObject);
    procedure edValueKeyUp(Sender: TObject; var Key: Word; Shift: TShiftState);
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    function Validate: Boolean;
    { private declarations }
  public
    CreditAccounts: TAccountIDs;
    DebitAccounts: TAccountIDs;
    fDefaultCreditAccID: Integer;
    fDefaultDebitAccID: Integer;
    procedure Init(CreditAccID, DebitAccID: Integer; CurrencyDetail: string);
    { public declarations }
  end; 

var
  fmEntryForm: TfmEntryForm;

implementation


{ TfmEntryForm }

uses AccountsTree, NumbersLib;

function TfmEntryForm.Validate: Boolean;
begin
  Result:= False;
  if Trim(edValue.Text) = '' then
    ShowMessage('يجب إدخال المبلغ')
  else
  if cbDebitAccount.ItemIndex = -1 then
    ShowMessage('يجب إختيار الحساب المدين')
  else
  if cbCreditAccount.ItemIndex = -1 then
    ShowMessage('يجب إختيار الحساب الدائن')
  else
  if Trim(edDetails.Text) = '' then
    ShowMessage('لابد من كتابة تفصيل العملية')
  else
    Result:= True;

end;

procedure TfmEntryForm.Init(CreditAccID, DebitAccID: Integer; CurrencyDetail: string);
begin
  fDefaultCreditAccID:= CreditAccID;
  fDefaultDebitAccID:= DebitAccID;
  edValue.Clear;
  laCurrency.Caption:= CurrencyDetail;
end;


procedure TfmEntryForm.bbOkClick(Sender: TObject);
var
  EntryID: Integer;
begin
  if Validate then
  begin
    EntryID:= dmData.GetEntryID;
    if EntryID <> -1 then
    begin
      if dmData.InsertTrans(DebitAccounts[cbDebitAccount.ItemIndex], EntryID, 1, 0, StrToFloat(Trim(edValue.Text)),
        edDetails.Text) and
      dmData.InsertTrans(CreditAccounts[cbCreditAccount.ItemIndex], EntryID, 1, StrToFloat(Trim(edValue.Text)), 0, edDetails.Text) then
        begin
          dmData.SQLTransaction1.Commit;
          ModalResult:= mrOK;
        end;
    end;
  end;

end;

procedure TfmEntryForm.bbCreditClick(Sender: TObject);
var
  i: Integer;
begin
  fmAccountsTree.Init(fDefaultCreditAccID, True, True);

  if fmAccountsTree.ShowModal = mrOK then
  begin
    for i:= 0 to High(CreditAccounts) do
      if fmAccountsTree.SelectedAccountID = CreditAccounts[i] then
      begin
        cbCreditAccount.ItemIndex:= i;
        Break;
      end;
  end;

end;

procedure TfmEntryForm.bbDebitClick(Sender: TObject);
var
  i: Integer;
begin
  fmAccountsTree.Init(fDefaultDebitAccID, True, True);

  if fmAccountsTree.ShowModal = mrOK then
  begin
    for i:= 0 to High(DebitAccounts) do
      if fmAccountsTree.SelectedAccountID = DebitAccounts[i] then
      begin
        cbDebitAccount.ItemIndex:= i;
        Break;
      end;
  end;
end;

procedure TfmEntryForm.edValueKeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
var
  Sum: Double;
begin
  if Key = 13 then
  begin
    if GetOperandsCount(edValue.Text) = 0 then
    begin
      if Validate then
        if MessageDlg('إدراج  هذه المعاملة', mtConfirmation, [mbYes, mbNo], 0) = mrYes then
          bbOkClick(nil);
    end
    else
    begin
      Sum:= NumbersLib.SimpleCalculate(edValue.Text);
      edValue.Text:= FloatToStr(Sum);;
    end;
  end;
end;

procedure TfmEntryForm.FormCreate(Sender: TObject);
begin

end;

procedure TfmEntryForm.FormShow(Sender: TObject);
begin
  edValue.SetFocus;
end;

initialization
  {$I entryform.lrs}

end.

