unit InsertCheque;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, LResources, Forms, Controls, Graphics, Dialogs,
  StdCtrls, Buttons, EditBtn;


type

  TChequeType = (ctOriginated, ctReceived);

  { TfmInsertCheque }

  TfmInsertCheque = class(TForm)
    bbOk: TBitBtn;
    bbSelAccount: TBitBtn;
    cbAccount: TComboBox;
    cbBank: TComboBox;
    cbDirection: TComboBox;
    deChequeDate: TDateEdit;
    edDetails: TEdit;
    edValue: TEdit;
    edChequeNo: TEdit;
    edAccountNo: TEdit;
    Label1: TLabel;
    laAccountTitle: TLabel;
    Label4: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    laChequeType: TLabel;
    laCurrency: TLabel;
    procedure bbOkClick(Sender: TObject);
    procedure bbSelAccountClick(Sender: TObject);
    procedure cbDirectionChange(Sender: TObject);
    procedure cbDirectionClick(Sender: TObject);
  private
    fChequeType: TChequeType;
    AccountIDs: array of Integer;
    BankIDs: array of Integer;
    { private declarations }
  public
    { public declarations }
    procedure Init(ChequeType: TChequeType; Currency: string);
    function Validate: Boolean;
  end; 

var
  fmInsertCheque: TfmInsertCheque;

implementation

{ TfmInsertCheque }

uses Data, AccountsTree, main;

procedure TfmInsertCheque.bbOkClick(Sender: TObject);
var
  Res: string;
  CreditAccountID, DebitAccountID: Integer;
begin
  if Validate then
    if dmData.IsOrigChequeInserted(BankIDs[cbBank.ItemIndex], edAccountNo.Text, edChequeNo.Text) then
      MessageDlg('هذا الشيك تم إدراجه في النظام', mtError, [mbOk], 0)
    else
    begin
      if cbDirection.ItemIndex = 0 then // Originated
        begin
          DebitAccountID:= AccountIDs[cbAccount.ItemIndex];
          CreditAccountID:= fmMain.OrigChequesAccID;
        end
        else
        if cbDirection.ItemIndex = 1 then // Received
        begin
          CreditAccountID:= AccountIDs[cbAccount.ItemIndex];
          DebitAccountID:= fmMain.RecChequesAccID;
        end;

      // Insert Cheque
      if dmData.InsertOrigCheque(BankIDs[cbBank.ItemIndex], edChequeNo.Text, edAccountNo.Text, CreditAccountID, DebitAccountID,
           cbDirection.ItemIndex + 1, StrToFloat(Trim(edValue.Text)),
           deChequeDate.Date, edDetails.Text, Res) then
           begin
             dmData.SQLTransaction1.Commit;
             ModalResult:= mrOK;
           end
           else
              MessageDlg('حدث خطأ أثناء إدراج الشيك' + #10 + Res, mtError, [mbOk], 0);
    end;
end;

procedure TfmInsertCheque.bbSelAccountClick(Sender: TObject);
var
  i: Integer;
begin
  fmAccountsTree.Init;
  if fmAccountsTree.ShowModal = mrOK then
  begin
    for i:= 0 to High(AccountIDs) do
      if fmAccountsTree.SelectedAccountID = AccountIDs[i] then
      begin
        cbAccount.ItemIndex:= i;
        Break;
      end;
  end;
end;

procedure TfmInsertCheque.cbDirectionChange(Sender: TObject);
begin
  if cbDirection.ItemIndex = 0 then
    laAccountTitle.Caption:= 'الحساب المدين'
  else
  if cbDirection.ItemIndex = 1 then
    laAccountTitle.Caption:= 'الحساب الدائن'
end;

procedure TfmInsertCheque.cbDirectionClick(Sender: TObject);
begin
end;

procedure TfmInsertCheque.Init(ChequeType: TChequeType; Currency: string);
begin
  laCurrency.Caption:= Currency;
  //fChequeType:= ChequeType;

  cbBank.ItemIndex:= -1;
  cbDirection.ItemIndex:= -1;
  edDetails.Clear;
  edValue.Clear;
  edAccountNo.Clear;
  edChequeNo.Clear;
  deChequeDate.Date:= Date + 1;

  cbAccount.ItemIndex:= -1;

  dmData.FillBanksBox(cbBank.Items, BankIDs);
  dmData.FillAccountsBox(cbAccount.Items, AccountIDs);
end;

function TfmInsertCheque.Validate: Boolean;
begin
  if (cbDirection.ItemIndex = -1) or (cbBank.ItemIndex = -1) or (Trim(edChequeNo.Text) = '') or (Trim(edAccountNo.Text) = '') or
    (Trim(edValue.Text) = '') or (cbAccount.ItemIndex = -1) or (Trim(edDetails.Text) = '') then
    begin
      Result:= False;
      MessageDlg('لابد من إدخال كافة الحقول', mtWarning, [mbOk], 0);
    end
    else
      Result:= True;
end;

initialization
  {$I insertcheque.lrs}

end.

