unit ModifyCheque;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, LResources, Forms, Controls, Graphics, Dialogs,
  StdCtrls, Buttons, EditBtn;

type

  { TfmModifyCheque }

  TfmModifyCheque = class(TForm)
    bbOk: TBitBtn;
    bbSelAccount: TBitBtn;
    cbAccount: TComboBox;
    deDelay: TDateEdit;
    edDetails: TEdit;
    laAccountTitle: TLabel;
    Label7: TLabel;
    laChequeValue: TLabel;
    laDelay: TLabel;
    laChequeDetails: TLabel;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    laAccountNo: TLabel;
    laBank: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    laOperation: TLabel;
    laChequeNo: TLabel;
    procedure bbOkClick(Sender: TObject);
    procedure bbSelAccountClick(Sender: TObject);
  private
    AccountIDs: array of Integer;
    { private declarations }
  public
    { public declarations }
    fChequeID, fCreditAccount, fDebitAccount: Integer;
    fOperationID: Integer;
    fChequeValue: Double;
    procedure Init(ChequeID, OperationID, CreditAccount, DebitAccount: Integer; ChequeValue: Double; Operation, ChequeNo, AccountNo,
      Bank, ChequeDetails: string; AColor: Integer = clBlack);
  end; 

var
  fmModifyCheque: TfmModifyCheque;

implementation

{ TfmModifyCheque }

uses Data, AccountsTree;

procedure TfmModifyCheque.bbOkClick(Sender: TObject);
var
  EntryID: Integer;
  Res: string;
  NewState: Integer;
  CreditAccountID, DebitAccountID: Integer;
  cBankID, cCreditAccID, cDebitAccID, cDirection, cStateID: Integer;
  cChequeNo, cAccountNo, cDetails: string;
  cChequeValue: Double;
  cEntryDate, cChequeDate: TDateTime;
  Success: Boolean;
begin
  NewState:= fOperationID;

  if NewState = 10 then // Delay cheque, reactivate it
    NewState:= 1;

  if not dmData.InsertOrigChequeTrans(fChequeID, fOperationID, edDetails.Text, Res) then
    ShowMessage('حدث خطأ ' + Res)
  else
  begin
    // Read cheque info
    dmData.GetChequeInfo(fChequeID, cBankID, cCreditAccID, cDebitAccID, cDirection, cStateID, cChequeNo, cAccountNo, cDetails,
      CChequeValue, cEntryDate, cChequeDate, Res);

    if fOperationID = 10 then
      dmData.DelayCheque(fChequeID, deDelay.Date, Res);

    if not dmData.UpdateOrigChequeState(fChequeID, NewState, Res) then
      ShowMessage('حدث خطأ' + Res)
    else
    if fOperationID = 2 then // Payment, cheque passed
    begin
      EntryID:= dmData.GetEntryID;
      if EntryID <> -1 then
      begin

        if cDirection = 1 then // Originated
        begin
          DebitAccountID:= cCreditAccID;
          CreditAccountID:= AccountIDs[cbAccount.ItemIndex];
        end
        else
        if cDirection = 2 then // Received
        begin
          DebitAccountID:= AccountIDs[cbAccount.ItemIndex];
          CreditAccountID:= cDebitAccID;
        end;

        // Insert double entry
        if dmData.InsertTrans(DebitAccountID, EntryID, 1, 0, fChequeValue, 'شيك: ' + laBank.Caption + ', #' + cChequeNo + ', ' +
             cAccountNo + ',' + edDetails.Text) and
           dmData.InsertTrans(CreditAccountID, EntryID, 1, fChequeValue, 0, 'شيك: ' + laBank.Caption + ', #' + cChequeNo + ', ' +
             cAccountNo + ',' + edDetails.Text) then
         begin
           // modify cheque CreditAccID or DebitAccID
           if cDirection = 1 then
             Success:= dmData.ChangeChequeCreditAccID(fChequeID, CreditAccountID, Res)
           else
             Success:= dmData.ChangeChequeDebitAccID(fChequeID, DebitAccountID, Res);

           if success then
           begin
             dmData.SQLTransaction1.Commit;
             ShowMessage('تم إدراج القيد المزدوج للشيك');
             ModalResult:= mrOK;
           end
           else
           begin
             dmData.SQLTransaction1.Rollback;
             ShowMessage('حدث خطأ: ' + Res);
           end;
         end;

      end;
    end
    else   // Withrdaw cheque
    if fOperationID in [3, 4] then
    begin
      // Reverse cheque
      EntryID:= dmData.GetEntryID;
      if dmData.InsertTrans(cDebitAccID, EntryID, 1, fChequeValue, 0, 'عكس شيك: ' + laBank.Caption + ', #' + cChequeNo + ', ' +
           cAccountNo + ',' + edDetails.Text) and
         dmData.InsertTrans(cCreditAccID, EntryID, 1, 0, fChequeValue, 'عكس شيك: ' + laBank.Caption + ', #' + cChequeNo + ', ' +
           cAccountNo + ',' + edDetails.Text) then
         begin
           ShowMessage('تم عكس الشيك');
           ModalResult:= mrOk;
         end;

    end
    else
      ModalResult:= mrOK;
  end;
end;

procedure TfmModifyCheque.bbSelAccountClick(Sender: TObject);
var
  i: Integer;
begin
  fmAccountsTree.Init;
  if fmAccountsTree.ShowModal = mrOK then
  begin
    for i:= 0 to High(AccountIDs) do
      if fmAccountsTree.SelectedAccountID = AccountIDs[i] then
      begin
        cbAccount.ItemIndex:= i;
        Break;
      end;
  end;

end;

procedure TfmModifyCheque.Init(ChequeID, OperationID, CreditAccount, DebitAccount: Integer; ChequeValue: Double; Operation,
  ChequeNo, AccountNo, Bank, ChequeDetails: string; AColor: Integer = clBlack);
begin
  laOperation.Caption:= Operation;
  laChequeNo.Caption:= ChequeNo;
  laAccountNo.Caption:= AccountNo;
  laBank.Caption:= Bank;
  laChequeDetails.Caption:= ChequeDetails;
  laChequeValue.Caption:= Format('%3f', [ChequeValue]);
  edDetails.Clear;
  dmData.FillAccountsBox(cbAccount.Items, AccountIDs);

  fChequeID:= ChequeID;
  fChequeValue:= ChequeValue;
  fCreditAccount:= CreditAccount;
  fDebitAccount:= DebitAccount;
  fOperationID:= OperationID;

  laDelay.Visible:= OperationID = 10;
  deDelay.Visible:= OperationID = 10;
  laAccountTitle.Visible:= OperationID = 2;
  cbAccount.Visible:= OperationID = 2;
  bbSelAccount.Visible:= OperationID = 2;

  deDelay.Date:= Date + 1;
  laOperation.Font.Color:= AColor;
end;

initialization
  {$I modifycheque.lrs}

end.

